==> nextcloud-21.0.8p0.tgz: nextcloud/apps/survey_client/l10n/pt_BR.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Último relatório enviado em: {on}",
    "An error occurred while sending your report." : "Erro ao enviar seu relatório.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Lista de aplicativos <em>(para cada aplicativo: nome, versão, status de habilitado)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Ambiente do banco de dados <em>(tipo, versão, tamanho do banco de dados)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informação de criptografia <em>(está habilitado?, qual é o módulo padrão?)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Número de compartilhamentos <em>(por tipo e configuração de permissão)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Ambiente PHP <em>(versão, limite de memória, tempo máx. execução, tamanho máx. de arquivo)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Detalhes do servidor <em>(versão, cache de memória usado, status de bloqueio/visualizações/avatares)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Estatística <em>(número de arquivos, usuários, armazenamentos por tipo, comentários e rótulos)</em>",
    "Usage survey" : "Pesquisa de uso",
    "Help improve Nextcloud" : "Ajude a melhorar o Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Você quer ajudar a melhorar o Nextcloud enviando dados anônimos sobre sua instalação e uso? Você pode desativar isso em qualquer momento nas configurações administrativas.",
    "Not now" : "Agora não",
    "Send usage" : "Enviar uso",
    "Never" : "Nunca",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Envia dados anônimos para o Nextcloud para ajudar a melhorá-lo.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Envia dados anônimos para o Nextcloud para ajudar a melhorá-lo. Você sempre \n        tem controle total do conteúdo enviado para o Nextcloud e pode desativar\n        isso novamente a qualquer momento.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Você pode ajudar a melhorar o Nextcloud enviando dados sobre sua instalação e uso.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Levamos sua privacidade muito a sério. O envio de dados está desabilitado por padrão e você pode escolher ser quer ativá-lo. Eles serão tornados anônimos e lhe será dada a opção de escolher o que compartilhar. Quando o servidor recebe um relatório, os anteriores são removidos. Envie um relatório vazio para excluir todos os dados atualmente armazenados no servidor.",
    "Send new report now" : "Enviar novo relatório agora",
    "Send usage survey monthly" : "Enviar mensalmente a pesquisa de uso",
    "Data to send" : "Dados a enviar",
    "Last report sent on: %s" : "Último relatório enviado em: %s",
    "Last report" : "Último relatório"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-23.0.5.tgz: nextcloud/apps/survey_client/l10n/pt_BR.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Último relatório enviado em: {on}",
    "An error occurred while sending your report." : "Erro ao enviar seu relatório.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Lista de aplicativos <em>(para cada aplicativo: nome, versão, status de habilitado)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Ambiente do banco de dados <em>(tipo, versão, tamanho do banco de dados)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informação de criptografia <em>(está habilitado?, qual é o módulo padrão?)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Número de compartilhamentos <em>(por tipo e configuração de permissão)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Ambiente PHP <em>(versão, limite de memória, tempo máx. execução, tamanho máx. de arquivo)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Detalhes do servidor <em>(versão, cache de memória usado, status de bloqueio/visualizações/avatares)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Estatística <em>(número de arquivos, usuários, armazenamentos por tipo, comentários e rótulos)</em>",
    "Usage survey" : "Pesquisa de uso",
    "Help improve Nextcloud" : "Ajude a melhorar o Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Você quer ajudar a melhorar o Nextcloud enviando dados anônimos sobre sua instalação e uso? Você pode desativar isso em qualquer momento nas configurações administrativas.",
    "Not now" : "Agora não",
    "Send usage" : "Enviar uso",
    "Never" : "Nunca",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Envia dados anônimos para o Nextcloud para ajudar a melhorá-lo.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Envia dados anônimos ao Nextcloud para nos ajudar a melhorar o Nextcloud. Vocês\n\t\tsempre tem controle total sobre o conteúdo enviado ao Nextcloud e pode desabilitar\n\t\tnovamente a qualquer momento.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Você pode ajudar a melhorar o Nextcloud enviando dados sobre sua instalação e uso.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Levamos sua privacidade muito a sério. O envio de dados está desabilitado por padrão e você pode escolher ser quer ativá-lo. Eles serão tornados anônimos e lhe será dada a opção de escolher o que compartilhar. Quando o servidor recebe um relatório, os anteriores são removidos. Envie um relatório vazio para excluir todos os dados atualmente armazenados no servidor.",
    "Send new report now" : "Enviar novo relatório agora",
    "Send usage survey monthly" : "Enviar mensalmente a pesquisa de uso",
    "Data to send" : "Dados a enviar",
    "Last report sent on: %s" : "Último relatório enviado em: %s",
    "Last report" : "Último relatório",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Envia dados anônimos para o Nextcloud para ajudar a melhorá-lo. Você sempre \n        tem controle total do conteúdo enviado para o Nextcloud e pode desativar\n        isso novamente a qualquer momento."
},
"nplurals=2; plural=(n > 1);");
